@@ -27,7 +27,7 @@
 #'
 #' @param option A character string indicating the colormap option to use. Four
 #' options are available: "magma" (or "A"), "inferno" (or "B"), "plasma" (or "C"),
-#' and "viridis" (or "D", the default option).
+#' "viridis" (or "D", the default option) and "cividis" (or "E").
 #'
 #' @author Bob Rudis \email{bob@@rud.is}
 #'
@@ -90,7 +90,7 @@ scale_colour_viridis <- scale_color_viridis
 #'
 #' @param option A character string indicating the colormap option to use. Four
 #' options are available: "magma" (or "A"), "inferno" (or "B"), "plasma" (or "C"),
-#' and "viridis" (or "D", the default option).
+#' "viridis" (or "D", the default option) and "cividis" (or "E").
 #'
 #' @rdname scale_viridis
 #'
@@ -141,7 +141,8 @@ scale_colour_viridis <- scale_color_viridis
 #'   gg + scale_fill_viridis(option="B") + labs(x="Virdis B", y=NULL),
 #'   gg + scale_fill_viridis(option="C") + labs(x="Virdis C", y=NULL),
 #'   gg + scale_fill_viridis(option="D") + labs(x="Virdis D", y=NULL),
-#'   ncol=2, nrow=2
+#'   gg + scale_fill_viridis(option="E") + labs(x="Virdis E", y=NULL),
+#'   ncol=3, nrow=2
 #' )
 #'
 #' @export
@@ -172,3 +173,6 @@ viridisLite::magma
 #' @export
 viridisLite::plasma
 
+#' @importFrom viridisLite cividis
+#' @export
+viridisLite::cividis
